Changes
=======

development
-----------

0.2.5
-----

Swapped "draft" and "live" positions to make it similar to original toggle, and also because it's
more natural this way.

0.2.4
-----

Sorting out PyPi wierdness

0.2.0
-----

First release
